/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RecoveryServicesVaultConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#classic_vmware_replication_enabled RecoveryServicesVault#classic_vmware_replication_enabled}
    */
    readonly classicVmwareReplicationEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#cross_region_restore_enabled RecoveryServicesVault#cross_region_restore_enabled}
    */
    readonly crossRegionRestoreEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#id RecoveryServicesVault#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#immutability RecoveryServicesVault#immutability}
    */
    readonly immutability?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#location RecoveryServicesVault#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#name RecoveryServicesVault#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#public_network_access_enabled RecoveryServicesVault#public_network_access_enabled}
    */
    readonly publicNetworkAccessEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#resource_group_name RecoveryServicesVault#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#sku RecoveryServicesVault#sku}
    */
    readonly sku: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#soft_delete_enabled RecoveryServicesVault#soft_delete_enabled}
    */
    readonly softDeleteEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#storage_mode_type RecoveryServicesVault#storage_mode_type}
    */
    readonly storageModeType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#tags RecoveryServicesVault#tags}
    */
    readonly tags?: {
        [key: string]: string;
    };
    /**
    * encryption block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#encryption RecoveryServicesVault#encryption}
    */
    readonly encryption?: RecoveryServicesVaultEncryption;
    /**
    * identity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#identity RecoveryServicesVault#identity}
    */
    readonly identity?: RecoveryServicesVaultIdentity;
    /**
    * monitoring block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#monitoring RecoveryServicesVault#monitoring}
    */
    readonly monitoring?: RecoveryServicesVaultMonitoring;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#timeouts RecoveryServicesVault#timeouts}
    */
    readonly timeouts?: RecoveryServicesVaultTimeouts;
}
export interface RecoveryServicesVaultEncryption {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#infrastructure_encryption_enabled RecoveryServicesVault#infrastructure_encryption_enabled}
    */
    readonly infrastructureEncryptionEnabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#key_id RecoveryServicesVault#key_id}
    */
    readonly keyId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#use_system_assigned_identity RecoveryServicesVault#use_system_assigned_identity}
    */
    readonly useSystemAssignedIdentity?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#user_assigned_identity_id RecoveryServicesVault#user_assigned_identity_id}
    */
    readonly userAssignedIdentityId?: string;
}
export declare function recoveryServicesVaultEncryptionToTerraform(struct?: RecoveryServicesVaultEncryptionOutputReference | RecoveryServicesVaultEncryption): any;
export declare class RecoveryServicesVaultEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RecoveryServicesVaultEncryption | undefined;
    set internalValue(value: RecoveryServicesVaultEncryption | undefined);
    private _infrastructureEncryptionEnabled?;
    get infrastructureEncryptionEnabled(): boolean | cdktf.IResolvable;
    set infrastructureEncryptionEnabled(value: boolean | cdktf.IResolvable);
    get infrastructureEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _keyId?;
    get keyId(): string;
    set keyId(value: string);
    get keyIdInput(): string | undefined;
    private _useSystemAssignedIdentity?;
    get useSystemAssignedIdentity(): boolean | cdktf.IResolvable;
    set useSystemAssignedIdentity(value: boolean | cdktf.IResolvable);
    resetUseSystemAssignedIdentity(): void;
    get useSystemAssignedIdentityInput(): boolean | cdktf.IResolvable | undefined;
    private _userAssignedIdentityId?;
    get userAssignedIdentityId(): string;
    set userAssignedIdentityId(value: string);
    resetUserAssignedIdentityId(): void;
    get userAssignedIdentityIdInput(): string | undefined;
}
export interface RecoveryServicesVaultIdentity {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#identity_ids RecoveryServicesVault#identity_ids}
    */
    readonly identityIds?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#type RecoveryServicesVault#type}
    */
    readonly type: string;
}
export declare function recoveryServicesVaultIdentityToTerraform(struct?: RecoveryServicesVaultIdentityOutputReference | RecoveryServicesVaultIdentity): any;
export declare class RecoveryServicesVaultIdentityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RecoveryServicesVaultIdentity | undefined;
    set internalValue(value: RecoveryServicesVaultIdentity | undefined);
    private _identityIds?;
    get identityIds(): string[];
    set identityIds(value: string[]);
    resetIdentityIds(): void;
    get identityIdsInput(): string[] | undefined;
    get principalId(): string;
    get tenantId(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface RecoveryServicesVaultMonitoring {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#alerts_for_all_job_failures_enabled RecoveryServicesVault#alerts_for_all_job_failures_enabled}
    */
    readonly alertsForAllJobFailuresEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#alerts_for_critical_operation_failures_enabled RecoveryServicesVault#alerts_for_critical_operation_failures_enabled}
    */
    readonly alertsForCriticalOperationFailuresEnabled?: boolean | cdktf.IResolvable;
}
export declare function recoveryServicesVaultMonitoringToTerraform(struct?: RecoveryServicesVaultMonitoringOutputReference | RecoveryServicesVaultMonitoring): any;
export declare class RecoveryServicesVaultMonitoringOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RecoveryServicesVaultMonitoring | undefined;
    set internalValue(value: RecoveryServicesVaultMonitoring | undefined);
    private _alertsForAllJobFailuresEnabled?;
    get alertsForAllJobFailuresEnabled(): boolean | cdktf.IResolvable;
    set alertsForAllJobFailuresEnabled(value: boolean | cdktf.IResolvable);
    resetAlertsForAllJobFailuresEnabled(): void;
    get alertsForAllJobFailuresEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _alertsForCriticalOperationFailuresEnabled?;
    get alertsForCriticalOperationFailuresEnabled(): boolean | cdktf.IResolvable;
    set alertsForCriticalOperationFailuresEnabled(value: boolean | cdktf.IResolvable);
    resetAlertsForCriticalOperationFailuresEnabled(): void;
    get alertsForCriticalOperationFailuresEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface RecoveryServicesVaultTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#create RecoveryServicesVault#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#delete RecoveryServicesVault#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#read RecoveryServicesVault#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault#update RecoveryServicesVault#update}
    */
    readonly update?: string;
}
export declare function recoveryServicesVaultTimeoutsToTerraform(struct?: RecoveryServicesVaultTimeouts | cdktf.IResolvable): any;
export declare class RecoveryServicesVaultTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RecoveryServicesVaultTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: RecoveryServicesVaultTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault azurerm_recovery_services_vault}
*/
export declare class RecoveryServicesVault extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_recovery_services_vault";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.76.0/docs/resources/recovery_services_vault azurerm_recovery_services_vault} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RecoveryServicesVaultConfig
    */
    constructor(scope: Construct, id: string, config: RecoveryServicesVaultConfig);
    private _classicVmwareReplicationEnabled?;
    get classicVmwareReplicationEnabled(): boolean | cdktf.IResolvable;
    set classicVmwareReplicationEnabled(value: boolean | cdktf.IResolvable);
    resetClassicVmwareReplicationEnabled(): void;
    get classicVmwareReplicationEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _crossRegionRestoreEnabled?;
    get crossRegionRestoreEnabled(): boolean | cdktf.IResolvable;
    set crossRegionRestoreEnabled(value: boolean | cdktf.IResolvable);
    resetCrossRegionRestoreEnabled(): void;
    get crossRegionRestoreEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _immutability?;
    get immutability(): string;
    set immutability(value: string);
    resetImmutability(): void;
    get immutabilityInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _publicNetworkAccessEnabled?;
    get publicNetworkAccessEnabled(): boolean | cdktf.IResolvable;
    set publicNetworkAccessEnabled(value: boolean | cdktf.IResolvable);
    resetPublicNetworkAccessEnabled(): void;
    get publicNetworkAccessEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _sku?;
    get sku(): string;
    set sku(value: string);
    get skuInput(): string | undefined;
    private _softDeleteEnabled?;
    get softDeleteEnabled(): boolean | cdktf.IResolvable;
    set softDeleteEnabled(value: boolean | cdktf.IResolvable);
    resetSoftDeleteEnabled(): void;
    get softDeleteEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _storageModeType?;
    get storageModeType(): string;
    set storageModeType(value: string);
    resetStorageModeType(): void;
    get storageModeTypeInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _encryption;
    get encryption(): RecoveryServicesVaultEncryptionOutputReference;
    putEncryption(value: RecoveryServicesVaultEncryption): void;
    resetEncryption(): void;
    get encryptionInput(): RecoveryServicesVaultEncryption | undefined;
    private _identity;
    get identity(): RecoveryServicesVaultIdentityOutputReference;
    putIdentity(value: RecoveryServicesVaultIdentity): void;
    resetIdentity(): void;
    get identityInput(): RecoveryServicesVaultIdentity | undefined;
    private _monitoring;
    get monitoring(): RecoveryServicesVaultMonitoringOutputReference;
    putMonitoring(value: RecoveryServicesVaultMonitoring): void;
    resetMonitoring(): void;
    get monitoringInput(): RecoveryServicesVaultMonitoring | undefined;
    private _timeouts;
    get timeouts(): RecoveryServicesVaultTimeoutsOutputReference;
    putTimeouts(value: RecoveryServicesVaultTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | RecoveryServicesVaultTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
